<?php

namespace Litecms\Recommendation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Recommendation\Models\Recommendation;

class RecommendationPolicy
{

    /**
     * Determine if the given user can view the recommendation.
     *
     * @param UserPolicy $user
     * @param Recommendation $recommendation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Recommendation $recommendation)
    {
        if ($user->canDo('recommendation.recommendation.view') && $user->isAdmin()) {
            return true;
        }

        return $recommendation->user_id == user_id() && $recommendation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a recommendation.
     *
     * @param UserPolicy $user
     * @param Recommendation $recommendation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('recommendation.recommendation.create');
    }

    /**
     * Determine if the given user can update the given recommendation.
     *
     * @param UserPolicy $user
     * @param Recommendation $recommendation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Recommendation $recommendation)
    {
        if ($user->canDo('recommendation.recommendation.edit') && $user->isAdmin()) {
            return true;
        }

        return $recommendation->user_id == user_id() && $recommendation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given recommendation.
     *
     * @param UserPolicy $user
     * @param Recommendation $recommendation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Recommendation $recommendation)
    {
        return $recommendation->user_id == user_id() && $recommendation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given recommendation.
     *
     * @param UserPolicy $user
     * @param Recommendation $recommendation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Recommendation $recommendation)
    {
        if ($user->canDo('recommendation.recommendation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given recommendation.
     *
     * @param UserPolicy $user
     * @param Recommendation $recommendation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Recommendation $recommendation)
    {
        if ($user->canDo('recommendation.recommendation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
